"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var youtubeplayer_common_1 = require("./youtubeplayer.common");
var observable_1 = require("tns-core-modules/data/observable");
var view_1 = require("tns-core-modules/ui/core/view");
var app = require("tns-core-modules/application");
var FRAGMENT_TAG = 'TNSYoutubeFragment';
var playerStyleProperty = new view_1.Property({
    name: 'playerStyle'
});
var YoutubePlayer = (function (_super) {
    __extends(YoutubePlayer, _super);
    function YoutubePlayer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    YoutubePlayer.prototype.createNativeView = function () {
        this._layoutId = android.view.View.generateViewId();
        var nativeView = new android.widget.LinearLayout(this._context);
        nativeView.setId(this._layoutId);
        var manager = app.android.foregroundActivity.getFragmentManager();
        var fragment = manager.findFragmentByTag(FRAGMENT_TAG);
        if (!fragment) {
            this._fragment = com.google.android.youtube.player.YouTubePlayerFragment.newInstance();
            manager
                .beginTransaction()
                .replace(this._layoutId, this._fragment, FRAGMENT_TAG)
                .commit();
        }
        else {
            this._fragment = fragment;
        }
        return nativeView;
    };
    YoutubePlayer.prototype.disposeNativeView = function () {
        this.destroy();
    };
    YoutubePlayer.prototype[youtubeplayer_common_1.srcProperty.setNative] = function (src) {
        if (this.player) {
            this.player.cueVideo(src);
        }
        else {
            this.initializePlayer();
        }
    };
    YoutubePlayer.prototype[youtubeplayer_common_1.apiKeyProperty.setNative] = function (apiKey) {
        this.initializePlayer();
    };
    YoutubePlayer.prototype[playerStyleProperty.getDefault] = function () {
        return 1;
    };
    YoutubePlayer.prototype[playerStyleProperty.setNative] = function (style) {
        if (this.player) {
            switch (style) {
                case 0:
                    this.player.setPlayerStyle(com.google.android.youtube.player.YouTubePlayer.PlayerStyle
                        .CHROMELESS);
                    break;
                case 1:
                    this.player.setPlayerStyle(com.google.android.youtube.player.YouTubePlayer.PlayerStyle.DEFAULT);
                    break;
                case 2:
                    this.player.setPlayerStyle(com.google.android.youtube.player.YouTubePlayer.PlayerStyle.MINIMAL);
                    break;
            }
        }
    };
    YoutubePlayer.prototype.initializePlayer = function () {
        if (!this._isInit && this.apiKey && this.src) {
            this._isInit = true;
            var that = new WeakRef(this);
            var owner_1 = that.get();
            var cb = new com.google.android.youtube.player.YouTubePlayer.OnInitializedListener({
                onInitializationFailure: function (provider, error) {
                    owner_1.notify({
                        eventName: 'error',
                        object: observable_1.fromObject({ message: error })
                    });
                },
                onInitializationSuccess: function (provider, player, wasRestored) {
                    owner_1.player = player;
                    var fullScreenCb = new com.google.android.youtube.player.YouTubePlayer.OnFullscreenListener({
                        onFullscreen: function (isFullscreen) {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.FULLSCREEN_EVENT,
                                object: observable_1.fromObject({
                                    value: isFullscreen
                                })
                            });
                        }
                    });
                    var playbackEventCb = new com.google.android.youtube.player.YouTubePlayer.PlaybackEventListener({
                        onBuffering: function (isBuffering) {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.BUFFERING_EVENT,
                                object: observable_1.fromObject({
                                    value: isBuffering
                                })
                            });
                        },
                        onPaused: function () {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.PAUSED_EVENT,
                                object: observable_1.fromObject({})
                            });
                        },
                        onPlaying: function () {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.PLAYING_EVENT,
                                object: observable_1.fromObject({})
                            });
                        },
                        onSeekTo: function (newPositionMillis) {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.SEEK_EVENT,
                                object: observable_1.fromObject({
                                    value: newPositionMillis
                                })
                            });
                        },
                        onStopped: function () {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.STOPPED_EVENT,
                                object: observable_1.fromObject({})
                            });
                        }
                    });
                    var playerStateChangeCb = new com.google.android.youtube.player.YouTubePlayer.PlayerStateChangeListener({
                        onAdStarted: function () {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.ADSTARTED_EVENT,
                                object: observable_1.fromObject({})
                            });
                        },
                        onError: function (reason) {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.ERROR_EVENT,
                                object: observable_1.fromObject({
                                    value: reason.toString()
                                })
                            });
                        },
                        onLoaded: function (videoId) {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.VIDEO_LOADED_EVENT,
                                object: observable_1.fromObject({
                                    value: videoId
                                })
                            });
                        },
                        onLoading: function () {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.LOADING_EVENT,
                                object: observable_1.fromObject({})
                            });
                        },
                        onVideoEnded: function () {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.ENDED_EVENT,
                                object: observable_1.fromObject({})
                            });
                        },
                        onVideoStarted: function () {
                            owner_1.notify({
                                eventName: youtubeplayer_common_1.STARTED_EVENT,
                                object: observable_1.fromObject({})
                            });
                        }
                    });
                    player.setPlayerStateChangeListener(playerStateChangeCb);
                    player.setPlaybackEventListener(playbackEventCb);
                    player.setOnFullscreenListener(fullScreenCb);
                    player.cueVideo(owner_1.src);
                }
            });
            this._fragment.initialize(this.apiKey, cb);
        }
    };
    YoutubePlayer.prototype.play = function () {
        if (this.player) {
            this.player.play();
        }
    };
    YoutubePlayer.prototype.stop = function () {
        if (this.player) {
            this.player.release();
        }
    };
    YoutubePlayer.prototype.destroy = function () {
        if (this.player) {
            this.player.release();
            this.player = null;
        }
        if (this._fragment) {
            var activity = app.android.foregroundActivity;
            if (activity && !activity.isFinishing()) {
                activity.getFragmentManager().beginTransaction().remove(this._fragment).commit();
                this._fragment = null;
            }
        }
    };
    YoutubePlayer.prototype.pause = function () {
        if (this.player) {
            this.player.pause();
        }
    };
    YoutubePlayer.prototype.isPlaying = function () {
        if (this.player) {
            return this.player.isPlaying();
        }
        return false;
    };
    YoutubePlayer.prototype.toggleFullscreen = function () {
        if (this.player) {
            this._fullScreen = !this._fullScreen;
            this.player.setFullscreen(this._fullScreen);
        }
    };
    Object.defineProperty(YoutubePlayer.prototype, "isFullScreen", {
        get: function () {
            return this._fullScreen;
        },
        enumerable: true,
        configurable: true
    });
    return YoutubePlayer;
}(youtubeplayer_common_1.YoutubePlayerBase));
exports.YoutubePlayer = YoutubePlayer;
playerStyleProperty.register(YoutubePlayer);
//# sourceMappingURL=youtubeplayer.android.js.map