"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var youtubeplayer_common_1 = require("./youtubeplayer.common");
var observable_1 = require("tns-core-modules/data/observable");
var utils = require("tns-core-modules/utils/utils");
var application = require("tns-core-modules/application");
var view_1 = require("tns-core-modules/ui/core/view");
var YoutubePlayer = (function (_super) {
    __extends(YoutubePlayer, _super);
    function YoutubePlayer() {
        var _this = _super.call(this) || this;
        _this._playerVars = NSDictionary.dictionaryWithObjectsForKeys([1, 2, 1, 1, 0, 1, 1, 0, 0, 1, 3], [
            'modestbranding',
            'controls',
            'playsinline',
            'autohide',
            'showinfo',
            'autoplay',
            'fs',
            'rel',
            'loop',
            'enablejsapi',
            'iv_load_policy'
        ]);
        _this.nativeView = YTPlayerView.new();
        _this.delegate = YTPlayerViewDelegateImpl.initWithOwner(new WeakRef(_this));
        return _this;
    }
    YoutubePlayer.prototype.initNativeView = function () {
        this.nativeView.delegate = this.delegate;
        _super.prototype.initNativeView.call(this);
    };
    YoutubePlayer.prototype[youtubeplayer_common_1.srcProperty.setNative] = function (src) {
        this.nativeView.loadWithVideoIdPlayerVars(src, this._playerVars);
    };
    YoutubePlayer.prototype[youtubeplayer_common_1.optionsProperty.setNative] = function (options) {
        var opts = NSDictionary.dictionaryWithDictionary(this.options);
        this._playerVars = opts;
        this.nativeView.loadWithPlayerParams(opts);
    };
    YoutubePlayer.prototype.onMeasure = function (widthMeasureSpec, heightMeasureSpec) {
        var nativeView = this.nativeView;
        if (nativeView) {
            var width = view_1.layout.getMeasureSpecSize(widthMeasureSpec);
            var height = view_1.layout.getMeasureSpecSize(heightMeasureSpec);
            this.setMeasuredDimension(width, height);
        }
    };
    YoutubePlayer.prototype.play = function () {
        this.nativeView.playVideo();
    };
    YoutubePlayer.prototype.pause = function () {
        this.nativeView.pauseVideo();
    };
    YoutubePlayer.prototype.stop = function () {
        this.nativeView.stopVideo();
    };
    YoutubePlayer.prototype.destroy = function () {
        var center = utils.ios.getter(NSNotificationCenter, NSNotificationCenter.defaultCenter);
        application.ios.removeNotificationObserver(this._observer, UIWindowDidResignKeyNotification);
        if (this.isPlaying) {
            this.nativeView.stopVideo();
            this.nativeView = null;
        }
        else {
            this.nativeView = null;
        }
    };
    YoutubePlayer.prototype.isPlaying = function () {
        return (this.nativeView.playerState() === 2);
    };
    YoutubePlayer.prototype.toggleFullscreen = function () {
        this.nativeView.fullScreen(!this._fullScreen);
    };
    Object.defineProperty(YoutubePlayer.prototype, "isFullScreen", {
        get: function () {
            return this._fullScreen;
        },
        enumerable: true,
        configurable: true
    });
    return YoutubePlayer;
}(youtubeplayer_common_1.YoutubePlayerBase));
exports.YoutubePlayer = YoutubePlayer;
var YTPlayerViewDelegateImpl = (function (_super) {
    __extends(YTPlayerViewDelegateImpl, _super);
    function YTPlayerViewDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    YTPlayerViewDelegateImpl.initWithOwner = function (owner) {
        var delegate = new YTPlayerViewDelegateImpl();
        delegate._owner = owner;
        return delegate;
    };
    YTPlayerViewDelegateImpl.prototype.playerViewDidChangeFullScreen = function (playerView, fullScreen) {
        var owner = this._owner.get();
        owner._fullScreen = fullScreen;
        owner.notify({
            eventName: youtubeplayer_common_1.FULLSCREEN_EVENT,
            object: observable_1.fromObject({
                value: fullScreen
            })
        });
    };
    YTPlayerViewDelegateImpl.prototype.playerViewDidBecomeReady = function (playerView) {
        var owner = this._owner.get();
        owner._observer = application.ios.addNotificationObserver(UIWindowDidResignKeyNotification, function (notification) {
            if (notification.object === application.ios.window &&
                !owner._fullScreen) {
                owner._fullScreen = true;
                owner.notify({
                    eventName: youtubeplayer_common_1.FULLSCREEN_EVENT,
                    object: observable_1.fromObject({
                        value: owner._fullScreen
                    })
                });
            }
            else if (notification.object !== application.ios.window &&
                owner._fullScreen) {
                owner._fullScreen = false;
                owner.notify({
                    eventName: youtubeplayer_common_1.FULLSCREEN_EVENT,
                    object: observable_1.fromObject({
                        value: owner._fullScreen
                    })
                });
            }
        });
        owner.notify({
            eventName: youtubeplayer_common_1.VIDEO_LOADED_EVENT,
            object: observable_1.fromObject({})
        });
    };
    YTPlayerViewDelegateImpl.prototype.playerViewDidChangeToState = function (playerView, state) {
        var owner = this._owner.get();
        switch (state) {
            case 4:
                owner.notify({
                    eventName: youtubeplayer_common_1.BUFFERING_EVENT,
                    object: observable_1.fromObject({})
                });
                break;
            case 1:
                owner.notify({
                    eventName: youtubeplayer_common_1.ENDED_EVENT,
                    object: observable_1.fromObject({})
                });
                break;
            case 3:
                owner.notify({
                    eventName: youtubeplayer_common_1.PAUSED_EVENT,
                    object: observable_1.fromObject({})
                });
                break;
            case 2:
                owner.notify({
                    eventName: youtubeplayer_common_1.PLAYING_EVENT,
                    object: observable_1.fromObject({})
                });
                break;
        }
    };
    YTPlayerViewDelegateImpl.prototype.playerViewReceivedError = function (playerView, error) {
        var owner = this._owner.get();
        switch (error) {
            case 0:
                owner.notify({
                    eventName: youtubeplayer_common_1.ERROR_EVENT,
                    object: observable_1.fromObject({
                        value: 'The request contains an invalid parameter value'
                    })
                });
                break;
            case 1:
                owner.notify({
                    eventName: youtubeplayer_common_1.ERROR_EVENT,
                    object: observable_1.fromObject({
                        value: 'The requested content cannot be played in an HTML5 player'
                    })
                });
                break;
            case 2:
                owner.notify({
                    eventName: youtubeplayer_common_1.ERROR_EVENT,
                    object: observable_1.fromObject({
                        value: 'The video requested was not found'
                    })
                });
                break;
            case 3:
                owner.notify({
                    eventName: youtubeplayer_common_1.ERROR_EVENT,
                    object: observable_1.fromObject({
                        value: 'The owner of the requested video does not allow it to be played in embedded players'
                    })
                });
                break;
            case 4:
                owner.notify({
                    eventName: youtubeplayer_common_1.ERROR_EVENT,
                    object: observable_1.fromObject({
                        value: 'Error occurred'
                    })
                });
                break;
        }
    };
    return YTPlayerViewDelegateImpl;
}(NSObject));
YTPlayerViewDelegateImpl.ObjCProtocols = [YTPlayerViewDelegate];
exports.YTPlayerViewDelegateImpl = YTPlayerViewDelegateImpl;
//# sourceMappingURL=youtubeplayer.ios.js.map